@@ -27,7 +27,9 @@ from sqlglot.expressions import (
     cast as cast,
     column as column,
     condition as condition,
+    delete as delete,
     except_ as except_,
+    find_tables as find_tables,
     from_ as from_,
     func as func,
     insert as insert,
