@@ -16,17 +16,19 @@ from sqlglot.dialects.dialect import (
     date_add_interval_sql,
     timestampdiff_sql,
 )
-from sqlglot.dialects.mysql import MySQL, _remove_ts_or_ds_to_date, date_add_sql
+from sqlglot.dialects.mysql import MySQL, _remove_ts_or_ds_to_date, date_add_sql, _show_parser
 from sqlglot.expressions import DataType
 from sqlglot.generator import unsupported_args
 from sqlglot.helper import seq_get
 
 
-def cast_to_time6(expression: t.Optional[exp.Expression]) -> exp.Cast:
+def cast_to_time6(
+    expression: t.Optional[exp.Expression], time_type: DataType.Type = exp.DataType.Type.TIME
+) -> exp.Cast:
     return exp.Cast(
         this=expression,
         to=exp.DataType.build(
-            exp.DataType.Type.TIME,
+            time_type,
             expressions=[exp.DataTypeParam(this=exp.Literal.number(6))],
         ),
     )
@@ -53,6 +55,17 @@ class SingleStore(MySQL):
         "FF6": "%f",  # only 6 digits are supported in python formats
     }
 
+    VECTOR_TYPE_ALIASES = {
+        "I8": "TINYINT",
+        "I16": "SMALLINT",
+        "I32": "INT",
+        "I64": "BIGINT",
+        "F32": "FLOAT",
+        "F64": "DOUBLE",
+    }
+
+    INVERSE_VECTOR_TYPE_ALIASES = {v: k for k, v in VECTOR_TYPE_ALIASES.items()}
+
     class Tokenizer(MySQL.Tokenizer):
         BYTE_STRINGS = [("e'", "'"), ("E'", "'")]
 
@@ -63,6 +76,7 @@ class SingleStore(MySQL):
             "TIMESTAMP": TokenType.TIMESTAMP,
             "UTC_DATE": TokenType.UTC_DATE,
             "UTC_TIME": TokenType.UTC_TIME,
+            "UTC_TIMESTAMP": TokenType.UTC_TIMESTAMP,
             ":>": TokenType.COLON_GT,
             "!:>": TokenType.NCOLON_GT,
             "::$": TokenType.DCOLONDOLLAR,
@@ -162,6 +176,8 @@ class SingleStore(MySQL):
                 json_type="JSON",
             ),
             "JSON_PRETTY": exp.JSONFormat.from_arg_list,
+            "JSON_BUILD_ARRAY": lambda args: exp.JSONArray(expressions=args),
+            "JSON_BUILD_OBJECT": lambda args: exp.JSONObject(expressions=args),
             "DATE": exp.Date.from_arg_list,
             "DAYNAME": lambda args: exp.TimeToStr(
                 this=seq_get(args, 0),
@@ -199,10 +215,19 @@ class SingleStore(MySQL):
             ),
         }
 
+        FUNCTION_PARSERS: t.Dict[str, t.Callable] = {
+            **MySQL.Parser.FUNCTION_PARSERS,
+            "JSON_AGG": lambda self: exp.JSONArrayAgg(
+                this=self._parse_term(),
+                order=self._parse_order(),
+            ),
+        }
+
         NO_PAREN_FUNCTIONS = {
             **MySQL.Parser.NO_PAREN_FUNCTIONS,
             TokenType.UTC_DATE: exp.UtcDate,
             TokenType.UTC_TIME: exp.UtcTime,
+            TokenType.UTC_TIMESTAMP: exp.UtcTimestamp,
         }
 
         CAST_COLUMN_OPERATORS = {TokenType.COLON_GT, TokenType.NCOLON_GT}
@@ -235,8 +260,67 @@ class SingleStore(MySQL):
         COLUMN_OPERATORS.pop(TokenType.DHASH_ARROW)
         COLUMN_OPERATORS.pop(TokenType.PLACEHOLDER)
 
+        SHOW_PARSERS = {
+            **MySQL.Parser.SHOW_PARSERS,
+            "AGGREGATES": _show_parser("AGGREGATES"),
+            "CDC EXTRACTOR POOL": _show_parser("CDC EXTRACTOR POOL"),
+            "CREATE AGGREGATE": _show_parser("CREATE AGGREGATE", target=True),
+            "CREATE PIPELINE": _show_parser("CREATE PIPELINE", target=True),
+            "CREATE PROJECTION": _show_parser("CREATE PROJECTION", target=True),
+            "DATABASE STATUS": _show_parser("DATABASE STATUS"),
+            "DISTRIBUTED_PLANCACHE STATUS": _show_parser("DISTRIBUTED_PLANCACHE STATUS"),
+            "FULLTEXT SERVICE METRICS LOCAL": _show_parser("FULLTEXT SERVICE METRICS LOCAL"),
+            "FULLTEXT SERVICE METRICS FOR NODE": _show_parser(
+                "FULLTEXT SERVICE METRICS FOR NODE", target=True
+            ),
+            "FULLTEXT SERVICE STATUS": _show_parser("FULLTEXT SERVICE STATUS"),
+            "FUNCTIONS": _show_parser("FUNCTIONS"),
+            "GROUPS": _show_parser("GROUPS"),
+            "GROUPS FOR ROLE": _show_parser("GROUPS FOR ROLE", target=True),
+            "GROUPS FOR USER": _show_parser("GROUPS FOR USER", target=True),
+            "INDEXES": _show_parser("INDEX", target="FROM"),
+            "KEYS": _show_parser("INDEX", target="FROM"),
+            "LINKS": _show_parser("LINKS", target="ON"),
+            "LOAD ERRORS": _show_parser("LOAD ERRORS"),
+            "LOAD WARNINGS": _show_parser("LOAD WARNINGS"),
+            "PARTITIONS": _show_parser("PARTITIONS", target="ON"),
+            "PIPELINES": _show_parser("PIPELINES"),
+            "PLAN": _show_parser("PLAN", target=True),
+            "PLANCACHE": _show_parser("PLANCACHE"),
+            "PROCEDURES": _show_parser("PROCEDURES"),
+            "PROJECTIONS": _show_parser("PROJECTIONS", target="ON TABLE"),
+            "REPLICATION STATUS": _show_parser("REPLICATION STATUS"),
+            "REPRODUCTION": _show_parser("REPRODUCTION"),
+            "RESOURCE POOLS": _show_parser("RESOURCE POOLS"),
+            "ROLES": _show_parser("ROLES"),
+            "ROLES FOR USER": _show_parser("ROLES FOR USER", target=True),
+            "ROLES FOR GROUP": _show_parser("ROLES FOR GROUP", target=True),
+            "STATUS EXTENDED": _show_parser("STATUS EXTENDED"),
+            "USERS": _show_parser("USERS"),
+            "USERS FOR ROLE": _show_parser("USERS FOR ROLE", target=True),
+            "USERS FOR GROUP": _show_parser("USERS FOR GROUP", target=True),
+        }
+
+        ALTER_PARSERS = {
+            **MySQL.Parser.ALTER_PARSERS,
+            "CHANGE": lambda self: self.expression(
+                exp.RenameColumn, this=self._parse_column(), to=self._parse_column()
+            ),
+        }
+
+        def _parse_vector_expressions(
+            self, expressions: t.List[exp.Expression]
+        ) -> t.List[exp.Expression]:
+            type_name = expressions[1].name.upper()
+            if type_name in self.dialect.VECTOR_TYPE_ALIASES:
+                type_name = self.dialect.VECTOR_TYPE_ALIASES[type_name]
+
+            return [exp.DataType.build(type_name, dialect=self.dialect), expressions[0]]
+
     class Generator(MySQL.Generator):
         SUPPORTS_UESCAPE = False
+        NULL_ORDERING_SUPPORTED = True
+        MATCH_AGAINST_TABLE_PREFIX = "TABLE "
 
         @staticmethod
         def _unicode_substitute(m: re.Match[str]) -> str:
@@ -339,6 +423,11 @@ class SingleStore(MySQL):
             if e.unit is not None
             else self.func("DATEDIFF", e.this, e.expression),
             exp.TimestampTrunc: unsupported_args("zone")(timestamptrunc_sql()),
+            exp.CurrentDatetime: lambda self, e: self.sql(
+                cast_to_time6(
+                    exp.CurrentTimestamp(this=exp.Literal.number(6)), exp.DataType.Type.DATETIME
+                )
+            ),
             exp.JSONExtract: unsupported_args(
                 "only_json_types",
                 "expressions",
@@ -354,6 +443,21 @@ class SingleStore(MySQL):
             exp.JSONPathSubscript: lambda self, e: self.json_path_part(e.this),
             exp.JSONPathRoot: lambda *_: "",
             exp.JSONFormat: unsupported_args("options", "is_json")(rename_func("JSON_PRETTY")),
+            exp.JSONArrayAgg: unsupported_args("null_handling", "return_type", "strict")(
+                lambda self, e: self.func("JSON_AGG", e.this, suffix=f"{self.sql(e, 'order')})")
+            ),
+            exp.JSONArray: unsupported_args("null_handling", "return_type", "strict")(
+                rename_func("JSON_BUILD_ARRAY")
+            ),
+            exp.JSONBExists: lambda self, e: self.func(
+                "BSON_MATCH_ANY_EXISTS", e.this, e.args.get("path")
+            ),
+            exp.JSONExists: unsupported_args("passing", "on_condition")(
+                lambda self, e: self.func("JSON_MATCH_ANY_EXISTS", e.this, e.args.get("path"))
+            ),
+            exp.JSONObject: unsupported_args(
+                "null_handling", "unique_keys", "return_type", "encoding"
+            )(rename_func("JSON_BUILD_OBJECT")),
             exp.DayOfWeekIso: lambda self, e: f"(({self.func('DAYOFWEEK', e.this)} % 7) + 1)",
             exp.DayOfMonth: rename_func("DAY"),
             exp.Hll: rename_func("APPROX_COUNT_DISTINCT"),
@@ -417,11 +521,44 @@ class SingleStore(MySQL):
                 ),
                 "RLIKE",
             ),
+            exp.Stuff: lambda self, e: self.func(
+                "CONCAT",
+                self.func("SUBSTRING", e.this, exp.Literal.number(1), e.args.get("start") - 1),
+                e.expression,
+                self.func("SUBSTRING", e.this, e.args.get("start") + e.args.get("length")),
+            ),
+            exp.National: lambda self, e: self.national_sql(e, prefix=""),
             exp.Reduce: unsupported_args("finish")(
                 lambda self, e: self.func(
                     "REDUCE", e.args.get("initial"), e.this, e.args.get("merge")
                 )
             ),
+            exp.MatchAgainst: unsupported_args("modifier")(
+                lambda self, e: super().matchagainst_sql(e)
+            ),
+            exp.Show: unsupported_args(
+                "history",
+                "terse",
+                "offset",
+                "starts_with",
+                "limit",
+                "from",
+                "scope",
+                "scope_kind",
+                "mutex",
+                "query",
+                "channel",
+                "log",
+                "types",
+                "privileges",
+            )(lambda self, e: super().show_sql(e)),
+            exp.Describe: unsupported_args(
+                "style",
+                "kind",
+                "expressions",
+                "partition",
+                "format",
+            )(lambda self, e: super().describe_sql(e)),
         }
         TRANSFORMS.pop(exp.JSONExtractScalar)
         TRANSFORMS.pop(exp.CurrentDate)
@@ -1640,6 +1777,14 @@ class SingleStore(MySQL):
                     return f"DECIMAL({precision}, {scale[0]})"
                 else:
                     return f"DECIMAL({precision})"
+            if expression.is_type(exp.DataType.Type.VECTOR):
+                expressions = expression.expressions
+                if len(expressions) == 2:
+                    type_name = self.sql(expressions[0])
+                    if type_name in self.dialect.INVERSE_VECTOR_TYPE_ALIASES:
+                        type_name = self.dialect.INVERSE_VECTOR_TYPE_ALIASES[type_name]
+
+                    return f"VECTOR({self.sql(expressions[1])}, {type_name})"
 
             return super().datatype_sql(expression)
 
@@ -1667,3 +1812,60 @@ class SingleStore(MySQL):
                 self.unsupported("CurrentTime with timezone is not supported in SingleStore")
 
             return self.func("CURRENT_TIME")
+
+        def currenttimestamp_sql(self, expression: exp.CurrentTimestamp) -> str:
+            arg = expression.this
+            if arg:
+                if isinstance(arg, exp.Literal) and arg.name.lower() == "utc":
+                    return self.func("UTC_TIMESTAMP")
+                if isinstance(arg, exp.Literal) and arg.is_number:
+                    return self.func("CURRENT_TIMESTAMP", arg)
+                self.unsupported("CurrentTimestamp with timezone is not supported in SingleStore")
+
+            return self.func("CURRENT_TIMESTAMP")
+
+        def standardhash_sql(self, expression: exp.StandardHash) -> str:
+            hash_function = expression.expression
+            if hash_function is None:
+                return self.func("SHA", expression.this)
+            if isinstance(hash_function, exp.Literal):
+                if hash_function.name.lower() == "sha":
+                    return self.func("SHA", expression.this)
+                if hash_function.name.lower() == "md5":
+                    return self.func("MD5", expression.this)
+
+                self.unsupported(
+                    f"{hash_function.this} hash method is not supported in SingleStore"
+                )
+                return self.func("SHA", expression.this)
+
+            self.unsupported("STANDARD_HASH function is not supported in SingleStore")
+            return self.func("SHA", expression.this)
+
+        @unsupported_args("is_database", "exists", "cluster", "identity", "option", "partition")
+        def truncatetable_sql(self, expression: exp.TruncateTable) -> str:
+            statements = []
+            for expression in expression.expressions:
+                statements.append(f"TRUNCATE {self.sql(expression)}")
+
+            return "; ".join(statements)
+
+        @unsupported_args("exists")
+        def renamecolumn_sql(self, expression: exp.RenameColumn) -> str:
+            old_column = self.sql(expression, "this")
+            new_column = self.sql(expression, "to")
+            return f"CHANGE {old_column} {new_column}"
+
+        @unsupported_args("drop", "comment", "allow_null", "visible", "using")
+        def altercolumn_sql(self, expression: exp.AlterColumn) -> str:
+            alter = super().altercolumn_sql(expression)
+
+            collate = self.sql(expression, "collate")
+            collate = f" COLLATE {collate}" if collate else ""
+            return f"{alter}{collate}"
+
+        def computedcolumnconstraint_sql(self, expression: exp.ComputedColumnConstraint) -> str:
+            this = self.sql(expression, "this")
+            not_null = " NOT NULL" if expression.args.get("not_null") else ""
+            type = self.sql(expression, "data_type") or "AUTO"
+            return f"AS {this} PERSISTED {type}{not_null}"
