@@ -1,4 +1,5 @@
-import os
+import ast
+import csv
 import datetime
 import unittest
 from datetime import date, time
@@ -9,7 +10,7 @@ import numpy as np
 import pandas as pd
 from pandas.testing import assert_frame_equal
 
-from sqlglot import exp, parse_one, transpile
+from sqlglot import exp, find_tables, parse_one, transpile
 from sqlglot.errors import ExecuteError
 from sqlglot.executor import execute
 from sqlglot.executor.python import Python
@@ -22,37 +23,94 @@ from tests.helpers import (
     TPCH_SCHEMA,
     TPCDS_SCHEMA,
     load_sql_fixture_pairs,
-    string_to_bool,
 )
 
 DIR_TPCH = FIXTURES_DIR + "/optimizer/tpc-h/"
 DIR_TPCDS = FIXTURES_DIR + "/optimizer/tpc-ds/"
 
 
+def open_file(file_name):
+    """Open a file that may be compressed as gzip and return it in universal newline mode."""
+    with open(file_name, "rb") as f:
+        gzipped = f.read(2) == b"\x1f\x8b"
+
+    if gzipped:
+        import gzip
+
+        return gzip.open(file_name, "rt", newline="")
+
+    return open(file_name, encoding="utf-8", newline="")
+
+
+_schema = None
+_tables = None
+
+
+def initializer(schema, tables):
+    global _schema, _tables
+    _schema = schema
+    _tables = tables
+
+
+def mp_execute(expression, meta):
+    if not meta.get("execute"):
+        return None
+
+    tables = {}
+
+    for t in find_tables(expression):
+        name = t.name
+        tables[name] = _tables[name]
+
+    return execute(expression, schema=_schema, tables=tables)
+
+
 @unittest.skipIf(SKIP_INTEGRATION, "Skipping Integration Tests since `SKIP_INTEGRATION` is set")
 class TestExecutor(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls.tpch_conn = duckdb.connect()
         cls.tpcds_conn = duckdb.connect()
+        cls.tpch_tables = {}
+        cls.tpcds_tables = {}
+
+        def setup(conn, directory, table, columns, tables):
+            file_name = f"{directory}{table}.csv.gz"
+
+            conn.execute(
+                f"""
+                CREATE VIEW {table} AS
+                SELECT *
+                FROM READ_CSV('{file_name}', delim='|', header=True, columns={columns})
+                """
+            )
+
+            reader = csv.reader(open_file(file_name), delimiter="|")
+            rows = []
+            ctypes = []
+            tables[table] = rows
+
+            next(reader)
+
+            for row in reader:
+                if not ctypes:
+                    for i, v in enumerate(row):
+                        try:
+                            ctypes.append(type(ast.literal_eval(v)))
+                        except (ValueError, SyntaxError):
+                            ctypes.append(str)
+
+                rows.append(
+                    tuple(None if (t is not str and v == "") else t(v) for t, v in zip(ctypes, row))
+                )
+
+            tables[table] = Table(columns=columns, rows=rows)
 
         for table, columns in TPCH_SCHEMA.items():
-            cls.tpch_conn.execute(
-                f"""
-                CREATE VIEW {table} AS
-                SELECT *
-                FROM READ_CSV('{DIR_TPCH}{table}.csv.gz', delim='|', header=True, columns={columns})
-                """
-            )
+            setup(cls.tpch_conn, DIR_TPCH, table, columns, cls.tpch_tables)
 
         for table, columns in TPCDS_SCHEMA.items():
-            cls.tpcds_conn.execute(
-                f"""
-                CREATE VIEW {table} AS
-                SELECT *
-                FROM READ_CSV('{DIR_TPCDS}{table}.csv.gz', delim='|', header=True, columns={columns})
-                """
-            )
+            setup(cls.tpcds_conn, DIR_TPCDS, table, columns, cls.tpcds_tables)
 
         cls.cache = {}
         cls.tpch_sqls = list(load_sql_fixture_pairs("optimizer/tpc-h/tpc-h.sql"))
@@ -99,40 +157,25 @@ class TestExecutor(unittest.TestCase):
             )
             assert_frame_equal(a, b, check_dtype=False, check_index_type=False)
 
-    def test_execute_tpch(self):
-        def to_csv(expression):
-            if isinstance(expression, exp.Table) and expression.name not in ("revenue"):
-                return parse_one(
-                    f"READ_CSV('{DIR_TPCH}{expression.name}.csv.gz', 'delimiter', '|') AS {expression.alias_or_name}"
-                )
-            return expression
-
-        with Pool() as pool:
+    def _mp_execute(self, schema, tables, sqls, tpch):
+        with Pool(
+            initializer=initializer,
+            initargs=(schema, tables),
+        ) as pool:
             for i, table in enumerate(
                 pool.starmap(
-                    execute,
-                    (
-                        (parse_one(sql).transform(to_csv).sql(pretty=True), TPCH_SCHEMA)
-                        for _, sql, _ in self.tpch_sqls
-                    ),
+                    mp_execute,
+                    ((parse_one(sql), args) for args, sql, _ in sqls),
                 )
             ):
-                self.subtestHelper(i, table, tpch=True)
+                if table is not None:
+                    self.subtestHelper(i, table, tpch=tpch)
+
+    def test_execute_tpch(self):
+        self._mp_execute(TPCH_SCHEMA, self.tpch_tables, self.tpch_sqls, True)
 
     def test_execute_tpcds(self):
-        def to_csv(expression):
-            if isinstance(expression, exp.Table) and os.path.exists(
-                f"{DIR_TPCDS}{expression.name}.csv.gz"
-            ):
-                return parse_one(
-                    f"READ_CSV('{DIR_TPCDS}{expression.name}.csv.gz', 'delimiter', '|') AS {expression.alias_or_name}"
-                )
-            return expression
-
-        for i, (meta, sql, _) in enumerate(self.tpcds_sqls):
-            if string_to_bool(meta.get("execute")):
-                table = execute(parse_one(sql).transform(to_csv).sql(pretty=True), TPCDS_SCHEMA)
-                self.subtestHelper(i, table, tpch=False)
+        self._mp_execute(TPCDS_SCHEMA, self.tpcds_tables, self.tpcds_sqls, False)
 
     def test_execute_callable(self):
         tables = {
@@ -837,19 +880,19 @@ class TestExecutor(unittest.TestCase):
     def test_nested_values(self):
         tables = {"foo": [{"raw": {"name": "Hello, World", "a": [{"b": 1}]}}]}
 
-        result = execute("SELECT raw:name AS name FROM foo", read="snowflake", tables=tables)
+        result = execute("SELECT raw:name AS name FROM foo", dialect="snowflake", tables=tables)
         self.assertEqual(result.columns, ("NAME",))
         self.assertEqual(result.rows, [("Hello, World",)])
 
-        result = execute("SELECT raw:a[0].b AS b FROM foo", read="snowflake", tables=tables)
+        result = execute("SELECT raw:a[0].b AS b FROM foo", dialect="snowflake", tables=tables)
         self.assertEqual(result.columns, ("B",))
         self.assertEqual(result.rows, [(1,)])
 
-        result = execute("SELECT raw:a[1].b AS b FROM foo", read="snowflake", tables=tables)
+        result = execute("SELECT raw:a[1].b AS b FROM foo", dialect="snowflake", tables=tables)
         self.assertEqual(result.columns, ("B",))
         self.assertEqual(result.rows, [(None,)])
 
-        result = execute("SELECT raw:a[0].c AS c FROM foo", read="snowflake", tables=tables)
+        result = execute("SELECT raw:a[0].c AS c FROM foo", dialect="snowflake", tables=tables)
         self.assertEqual(result.columns, ("C",))
         self.assertEqual(result.rows, [(None,)])
 
@@ -860,7 +903,9 @@ class TestExecutor(unittest.TestCase):
                 {"id": 3, "attributes": {"flavor": "apple", "taste": None}},
             ]
         }
-        result = execute("SELECT i.attributes.flavor FROM `ITEM` i", read="bigquery", tables=tables)
+        result = execute(
+            "SELECT i.attributes.flavor FROM `ITEM` i", dialect="bigquery", tables=tables
+        )
 
         self.assertEqual(result.columns, ("flavor",))
         self.assertEqual(result.rows, [("cherry",), ("lime",), ("apple",)])
@@ -885,3 +930,13 @@ class TestExecutor(unittest.TestCase):
             "avg_bill_length",
             "avg_bill_depth",
         ]
+
+    def test_table_to_pylist(self):
+        columns = ["id", "product", "price"]
+        rows = [[1, "Shirt", 20.0], [2, "Shoes", 60.0]]
+        table = Table(columns=columns, rows=rows)
+        expected = [
+            {"id": 1, "product": "Shirt", "price": 20.0},
+            {"id": 2, "product": "Shoes", "price": 60.0},
+        ]
+        self.assertEqual(table.to_pylist(), expected)
