@@ -73,6 +73,15 @@ class TestExpressions(unittest.TestCase):
         self.assertEqual(
             exp.DataType.build("int"), exp.DataType(this=exp.DataType.Type.INT, nested=False)
         )
+        self.assertNotEqual(
+            exp.Identifier(this="a", temporary=True),
+            exp.Identifier(this="a"),
+        )
+
+    def test_eq_on_same_instance_short_circuits(self):
+        expr = parse_one("1")
+        expr == expr
+        self.assertIsNone(expr._hash)
 
     def test_find(self):
         expression = parse_one("CREATE TABLE x STORED AS PARQUET AS SELECT * FROM y")
@@ -669,6 +678,8 @@ class TestExpressions(unittest.TestCase):
         self.assertIsInstance(parse_one("ARRAY_AGG(a)"), exp.ArrayAgg)
         self.assertIsInstance(parse_one("ARRAY_CONTAINS(a, 'a')"), exp.ArrayContains)
         self.assertIsInstance(parse_one("ARRAY_SIZE(a)"), exp.ArraySize)
+        self.assertIsInstance(parse_one("ARRAY_INTERSECTION([1, 2], [2, 3])"), exp.ArrayIntersect)
+        self.assertIsInstance(parse_one("ARRAY_INTERSECT([1, 2], [2, 3])"), exp.ArrayIntersect)
         self.assertIsInstance(parse_one("AVG(a)"), exp.Avg)
         self.assertIsInstance(parse_one("BEGIN DEFERRED TRANSACTION"), exp.Transaction)
         self.assertIsInstance(parse_one("CEIL(a)"), exp.Ceil)
@@ -680,6 +691,7 @@ class TestExpressions(unittest.TestCase):
         self.assertIsInstance(parse_one("DATE_ADD(a, 1)"), exp.DateAdd)
         self.assertIsInstance(parse_one("DATE_DIFF(a, 2)"), exp.DateDiff)
         self.assertIsInstance(parse_one("DATE_STR_TO_DATE(a)"), exp.DateStrToDate)
+        self.assertIsInstance(parse_one("TS_OR_DS_TO_TIME(a)"), exp.TsOrDsToTime)
         self.assertIsInstance(parse_one("DAY(a)"), exp.Day)
         self.assertIsInstance(parse_one("EXP(a)"), exp.Exp)
         self.assertIsInstance(parse_one("FLOOR(a)"), exp.Floor)
@@ -710,6 +722,8 @@ class TestExpressions(unittest.TestCase):
         self.assertIsInstance(parse_one("ROUND(a)"), exp.Round)
         self.assertIsInstance(parse_one("ROUND(a, 2)"), exp.Round)
         self.assertIsInstance(parse_one("SPLIT(a, 'test')"), exp.Split)
+        self.assertIsInstance(parse_one("ST_POINT(10, 20)"), exp.StPoint)
+        self.assertIsInstance(parse_one("ST_DISTANCE(a, b)"), exp.StDistance)
         self.assertIsInstance(parse_one("STR_POSITION(a, 'test')"), exp.StrPosition)
         self.assertIsInstance(parse_one("STR_TO_UNIX(a, 'format')"), exp.StrToUnix)
         self.assertIsInstance(parse_one("STRUCT_EXTRACT(a, 'test')"), exp.StructExtract)
@@ -752,6 +766,9 @@ class TestExpressions(unittest.TestCase):
         self.assertIsInstance(parse_one("ADD_MONTHS(a, b)"), exp.AddMonths)
 
     def test_column(self):
+        column = exp.column(exp.Star(), table="t")
+        self.assertEqual(column.sql(), "t.*")
+
         column = parse_one("a.b.c.d")
         self.assertEqual(column.catalog, "a")
         self.assertEqual(column.db, "b")
@@ -987,15 +1004,20 @@ FROM foo""",
         self.assertEqual(table_only.name, "table_name")
         self.assertIsNone(table_only.args.get("db"))
         self.assertIsNone(table_only.args.get("catalog"))
+
         db_and_table = exp.to_table("db.table_name")
         self.assertEqual(db_and_table.name, "table_name")
         self.assertEqual(db_and_table.args.get("db"), exp.to_identifier("db"))
         self.assertIsNone(db_and_table.args.get("catalog"))
+
         catalog_db_and_table = exp.to_table("catalog.db.table_name")
         self.assertEqual(catalog_db_and_table.name, "table_name")
         self.assertEqual(catalog_db_and_table.args.get("db"), exp.to_identifier("db"))
         self.assertEqual(catalog_db_and_table.args.get("catalog"), exp.to_identifier("catalog"))
 
+        table_only_unsafe_identifier = exp.to_table("3e")
+        self.assertEqual(table_only_unsafe_identifier.sql(), '"3e"')
+
     def test_to_column(self):
         column_only = exp.to_column("column_name")
         self.assertEqual(column_only.name, "column_name")
@@ -1218,3 +1240,38 @@ FROM foo""",
 
     def test_parse_identifier(self):
         self.assertEqual(exp.parse_identifier("a ' b"), exp.to_identifier("a ' b"))
+
+    def test_convert_datetime_time(self):
+        # Test converting datetime.time objects to TsOrDsToTime expressions
+        time_obj = datetime.time(14, 30, 45)
+        result = exp.convert(time_obj)
+
+        self.assertIsInstance(result, exp.TsOrDsToTime)
+        self.assertIsInstance(result.this, exp.Literal)
+        self.assertEqual(result.sql(), "CAST('14:30:45' AS TIME)")
+        self.assertTrue(result.this.is_string)
+
+        # Test with microseconds
+        time_with_microseconds = datetime.time(9, 15, 30, 123456)
+        result = exp.convert(time_with_microseconds)
+
+        self.assertIsInstance(result, exp.TsOrDsToTime)
+        self.assertEqual(result.sql(), "CAST('09:15:30.123456' AS TIME)")
+
+        # Test midnight
+        midnight = datetime.time(0, 0, 0)
+        result = exp.convert(midnight)
+
+        self.assertIsInstance(result, exp.TsOrDsToTime)
+        self.assertEqual(result.sql(), "CAST('00:00:00' AS TIME)")
+
+        # Test noon
+        noon = datetime.time(12, 0, 0)
+        result = exp.convert(noon)
+
+        self.assertIsInstance(result, exp.TsOrDsToTime)
+        self.assertEqual(result.sql(), "CAST('12:00:00' AS TIME)")
+
+    def test_hash_large_ast(self):
+        expr = parse_one("SELECT 1 UNION ALL " * 3000 + "SELECT 1")
+        assert expr == expr
