@@ -42,6 +42,22 @@ class TestLineage(unittest.TestCase):
         self.assertEqual(downstream.source_name, "y")
         self.assertGreater(len(node.to_html()._repr_html_()), 1000)
 
+        # test that sql is not modified
+        sql = "SELECT a FROM x"
+        ast = sqlglot.parse_one(sql)
+        node = lineage("a", ast)
+        self.assertEqual(ast.sql(), sql)
+
+        # test that sources are not modified
+        ast = sqlglot.parse_one(sql)
+
+        source_sql = "SELECT a FROM y"
+        source = sqlglot.parse_one(source_sql)
+
+        node = lineage("a", ast, sources={"x": source})
+
+        self.assertEqual(source.sql(), source_sql)
+
     def test_lineage_sql_with_cte(self) -> None:
         node = lineage(
             "a",
@@ -123,6 +139,44 @@ class TestLineage(unittest.TestCase):
         self.assertEqual(downstream.source_name, "")
         self.assertEqual(downstream.reference_node_name, "y")
 
+    def test_lineage_join_with_star(self) -> None:
+        node = lineage(
+            "*",
+            "SELECT * from x JOIN y USING (uid)",
+        )
+        self.assertEqual(
+            node.source.sql(),
+            "SELECT * FROM x AS x JOIN y AS y ON x.uid = y.uid",
+        )
+        self.assertEqual(node.source_name, "")
+        self.assertEqual(node.reference_node_name, "")
+        self.assertEqual(len(node.downstream), 2)
+
+        downstream = node.downstream[0]
+        self.assertEqual(downstream.expression.sql(), "x AS x")
+        self.assertEqual(downstream.name, "*")
+
+        downstream = node.downstream[1]
+        self.assertEqual(downstream.expression.sql(), "y AS y")
+        self.assertEqual(downstream.name, "*")
+
+    def test_lineage_join_with_qualified_star(self) -> None:
+        node = lineage(
+            "*",
+            "SELECT x.* from x JOIN y USING (uid)",
+        )
+        self.assertEqual(
+            node.source.sql(),
+            "SELECT x.* FROM x AS x JOIN y AS y ON x.uid = y.uid",
+        )
+        self.assertEqual(node.source_name, "")
+        self.assertEqual(node.reference_node_name, "")
+        self.assertEqual(len(node.downstream), 1)
+
+        downstream = node.downstream[0]
+        self.assertEqual(downstream.expression.sql(), "x AS x")
+        self.assertEqual(downstream.name, "x.*")
+
     def test_lineage_external_col(self) -> None:
         node = lineage(
             "a",
@@ -262,10 +316,12 @@ class TestLineage(unittest.TestCase):
         downstream = downstream.downstream[0]
         self.assertEqual(downstream.name, "TABLE.A")
         self.assertEqual(
-            downstream.source.sql(dialect="snowflake"), "SNOWFLAKE.SCHEMA.TABLE AS TABLE"
+            downstream.source.sql(dialect="snowflake"),
+            "SNOWFLAKE.SCHEMA.TABLE AS TABLE",
         )
         self.assertEqual(
-            downstream.expression.sql(dialect="snowflake"), "SNOWFLAKE.SCHEMA.TABLE AS TABLE"
+            downstream.expression.sql(dialect="snowflake"),
+            "SNOWFLAKE.SCHEMA.TABLE AS TABLE",
         )
 
     def test_subquery(self) -> None:
@@ -467,7 +523,8 @@ class TestLineage(unittest.TestCase):
         downstream = node.downstream[0]
         self.assertEqual(downstream.name, "SUBQ.Y")
         self.assertEqual(
-            downstream.expression.sql(dialect="oracle"), "TO_DATE('2023-12-19', 'YYYY-MM-DD') AS Y"
+            downstream.expression.sql(dialect="oracle"),
+            "TO_DATE('2023-12-19', 'YYYY-MM-DD') AS Y",
         )
 
     def test_trim(self) -> None:
@@ -650,10 +707,61 @@ class TestLineage(unittest.TestCase):
         self.assertEqual(node.downstream[0].name, "cte.product_type")
         self.assertEqual(node.downstream[0].downstream[0].name, "_q_0.product_type")
         self.assertEqual(
-            node.downstream[0].downstream[0].downstream[0].name, "loan_ledger.product_type"
+            node.downstream[0].downstream[0].downstream[0].name,
+            "loan_ledger.product_type",
         )
 
         node = lineage('"2024-10"', sql, dialect="duckdb", schema=schema)
         self.assertEqual(node.downstream[0].name, "cte.2024-10")
         self.assertEqual(node.downstream[0].downstream[0].name, "_q_0.loan_id")
         self.assertEqual(node.downstream[0].downstream[0].downstream[0].name, "loan_ledger.loan_id")
+
+    def test_copy_flag(self) -> None:
+        schema = {
+            "x": {
+                "a": "int",
+            },
+        }
+
+        query = sqlglot.parse_one("SELECT a FROM z")
+        sources = {
+            "y": sqlglot.parse_one("SELECT * FROM x"),
+            "z": sqlglot.parse_one("SELECT * FROM y"),
+        }
+
+        lineage("a", query, schema=schema, sources=sources, copy=False)
+
+        self.assertEqual(sources["y"].sql(), "SELECT * FROM x")
+        self.assertEqual(sources["z"].sql(), "SELECT * FROM y")
+        self.assertEqual(
+            query.sql(),
+            "SELECT z.a AS a FROM (SELECT y.a AS a FROM (SELECT x.a AS a FROM x AS x) AS y /* source: y */) AS z /* source: z */",
+        )
+
+        query = sqlglot.parse_one("SELECT a FROM z")
+        sources = {
+            "y": sqlglot.parse_one("SELECT * FROM x"),
+            "z": sqlglot.parse_one("SELECT * FROM y"),
+        }
+
+        lineage("a", query, schema=schema, sources=sources, copy=True)
+
+        self.assertEqual(sources["y"].sql(), "SELECT * FROM x")
+        self.assertEqual(sources["z"].sql(), "SELECT * FROM y")
+        self.assertEqual(query.sql(), "SELECT a FROM z")
+
+        query = sqlglot.parse_one("SELECT a FROM z")
+        sources = {
+            "y": sqlglot.parse_one("SELECT * FROM x"),
+            "z": sqlglot.parse_one("SELECT * FROM y"),
+        }
+
+        query = sqlglot.parse_one("SELECT a FROM x")
+        lineage("a", query, schema=schema, copy=False)
+
+        self.assertEqual(query.sql(), "SELECT x.a AS a FROM x AS x")
+
+        query = sqlglot.parse_one("SELECT a FROM x")
+        lineage("a", query, schema=schema, copy=True)
+
+        self.assertEqual(query.sql(), "SELECT a FROM x")
